/*
 * Sixth 3D engine. Copyright ©2012-2018, Svjatoslav Agejenko, svjatoslav@svjatoslav.eu
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of version 3 of the GNU Lesser General Public License
 * or later as published by the Free Software Foundation.
 *
 */

package eu.svjatoslav.sixth.e3d.gui;

public interface ViewRenderListener {

    /**
     * Notifies that it is about time to render next frame and
     * allows listener to do any related processing that it needs to.
     * <p>
     * Each {@link ViewRenderListener} will be notified exactly once before every frame is rendered.
     * <p>
     * {@link ViewRenderListener} can determine if frame repaint is actually
     * needed from its perspective. Frame will be rendered only if at least one listener says yes.
     *
     * @return <code>true</code> if underlying view shall be re-rendered. If at least one of the view update listeners
     * returns <code>true</code>, view is re-rendered.
     */
    boolean beforeRender(ViewPanel viewPanel, final int millisecondsSinceLastFrame);
}
