/*
 * Sixth - System for data storage, computation, exploration and interaction.
 * Copyright ©2012-2018, Svjatoslav Agejenko, svjatoslav@svjatoslav.eu
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of version 3 of the GNU Lesser General Public License
 * or later as published by the Free Software Foundation.
 */

package eu.svjatoslav.sixth.e3d.gui.textEditorComponent;

import org.junit.Test;

import static org.junit.Assert.assertEquals;

public class TextLineTest {

    @Test
    public void testAddIdent() {
        TextLine textLine = new TextLine("test");
        textLine.addIdent(4);
        assertEquals("    test", textLine.toString());

        textLine = new TextLine();
        textLine.addIdent(4);
        assertEquals("", textLine.toString());
    }

    @Test
    public void testCutFromBeginning() {
        TextLine textLine = new TextLine("test");
        textLine.cutFromBeginning(2);
        assertEquals("st", textLine.toString());

        textLine = new TextLine("test");
        textLine.cutFromBeginning(4);
        assertEquals("", textLine.toString());

        textLine = new TextLine("test");
        textLine.cutFromBeginning(5);
        assertEquals("", textLine.toString());

        textLine = new TextLine("test");
        textLine.cutFromBeginning(100);
        assertEquals("", textLine.toString());
    }

    @Test
    public void testCutSubString() {
        TextLine textLine = new TextLine("test");
        assertEquals("es", textLine.cutSubString(1, 3));
        assertEquals("tt", textLine.toString());

        textLine = new TextLine("test");
        assertEquals("st ", textLine.cutSubString(2, 5));
        assertEquals("te", textLine.toString());
    }

    @Test
    public void testGetCharForLocation() {
        final TextLine textLine = new TextLine("test");
        assertEquals('s', textLine.getCharForLocation(2));
        assertEquals('t', textLine.getCharForLocation(3));
        assertEquals(' ', textLine.getCharForLocation(4));
    }

    @Test
    public void testGetIdent() {
        final TextLine textLine = new TextLine("   test");
        assertEquals(3, textLine.getIdent());
    }

    @Test
    public void testGetLength() {
        final TextLine textLine = new TextLine("test");
        assertEquals(4, textLine.getLength());
    }

    @Test
    public void testInsertCharacter() {
        TextLine textLine = new TextLine("test");
        textLine.insertCharacter(1, 'o');
        assertEquals("toest", textLine.toString());

        textLine = new TextLine("test");
        textLine.insertCharacter(5, 'o');
        assertEquals("test o", textLine.toString());

    }

    @Test
    public void testIsEmpty() {
        TextLine textLine = new TextLine("");
        assertEquals(true, textLine.isEmpty());

        textLine = new TextLine("     ");
        assertEquals(true, textLine.isEmpty());

        textLine = new TextLine("l");
        assertEquals(false, textLine.isEmpty());
    }

    @Test
    public void testRemoveCharacter() {
        TextLine textLine = new TextLine("test");
        textLine.removeCharacter(0);
        assertEquals("est", textLine.toString());

        textLine = new TextLine("test");
        textLine.removeCharacter(3);
        assertEquals("tes", textLine.toString());

        textLine = new TextLine("test");
        textLine.removeCharacter(4);
        assertEquals("test", textLine.toString());
    }

}
